package com.dcs.dcs.service;

import java.util.List;
import com.dcs.dcs.domain.DcsFlow;

/**
 * 流程Service接口
 * 
 * @author hmy
 * @date 2025-03-08
 */
public interface IDcsFlowService 
{
    /**
     * 查询流程
     * 
     * @param flowId 流程主键
     * @return 流程
     */
    public DcsFlow selectDcsFlowByFlowId(Long flowId);

    /**
     * 查询流程列表
     * 
     * @param dcsFlow 流程
     * @return 流程集合
     */
    public List<DcsFlow> selectDcsFlowList(DcsFlow dcsFlow);

    /**
     * 新增流程
     * 
     * @param dcsFlow 流程
     * @return 结果
     */
    public int insertDcsFlow(DcsFlow dcsFlow);

    /**
     * 修改流程
     * 
     * @param dcsFlow 流程
     * @return 结果
     */
    public int updateDcsFlow(DcsFlow dcsFlow);

    /**
     * 批量删除流程
     * 
     * @param flowIds 需要删除的流程主键集合
     * @return 结果
     */
    public int deleteDcsFlowByFlowIds(Long[] flowIds);

    /**
     * 删除流程信息
     * 
     * @param flowId 流程主键
     * @return 结果
     */
    public int deleteDcsFlowByFlowId(Long flowId);

    /**
     * 获取流程名称
     */
    public String selectFlowNameByFlowId(Long flowId);

    /**
     * 根据设备id获取流程列表
     * @param equipmentId
     * @return
     */
    List<DcsFlow> getFlowListByEquipmentId(Long equipmentId);
}
